@@ -22,6 +22,7 @@ function.
 
 // Tenacity libraries
 #include <lib-ffmpeg-support/FFmpegFunctions.h>
+#include <lib-ffmpeg-support/FifoBuffer.h>
 #include <lib-exceptions/InconsistencyException.h>
 #include <lib-files/wxFileNameWrapper.h>
 
@@ -176,7 +177,7 @@ private:
    bool              mSupportsUTF8{};
 
    // Smart pointer fields, their order is the reverse in which they are reset in FreeResources():
-   std::unique_ptr<AVFifoBufferWrapper> mEncAudioFifo; // FIFO to write incoming audio samples into
+   std::unique_ptr<FifoBuffer> mEncAudioFifo; // FIFO to write incoming audio samples into
    AVDataBuffer<int16_t> mEncAudioFifoOutBuf; // buffer to read _out_ of the FIFO into
    std::unique_ptr<AVFormatContextWrapper> mEncFormatCtx; // libavformat's context for our output file
    std::unique_ptr<AVCodecContextWrapper> mEncAudioCodecCtx;    // the encoder for the output audio stream
@@ -590,9 +591,7 @@ bool ExportFFmpeg::InitCodecs(TenacityProject *project)
 
    mEncAudioCodecCtx->SetGlobalQuality(mEncAudioCodecCtx->GetGlobalQuality() * AUDACITY_FF_QP2LAMBDA);
    mEncAudioCodecCtx->SetSampleRate(mSampleRate);
-   mEncAudioCodecCtx->SetChannels(mChannels);
-   mEncAudioCodecCtx->SetChannelLayout(mFFmpeg->av_get_default_channel_layout(mChannels));
-   mEncAudioCodecCtx->SetTimeBase({ 1, mSampleRate });
+   mEncAudioCodecCtx->SetChannelLayout(mFFmpeg->CreateDefaultChannelLayout(mChannels).get());   mEncAudioCodecCtx->SetTimeBase({ 1, mSampleRate });
    mEncAudioCodecCtx->SetSampleFmt(static_cast<AVSampleFormatFwd>(AUDACITY_AV_SAMPLE_FMT_S16));
    mEncAudioCodecCtx->SetStrictStdCompliance(
       AUDACITY_FF_COMPLIANCE_EXPERIMENTAL);
@@ -736,7 +735,7 @@ bool ExportFFmpeg::InitCodecs(TenacityProject *project)
    // The encoder may require a minimum number of raw audio samples for each encoding but we can't
    // guarantee we'll get this minimum each time an audio frame is decoded from the input file so
    // we use a FIFO to store up incoming raw samples until we have enough for one call to the codec.
-   mEncAudioFifo = mFFmpeg->CreateFifoBuffer(mDefaultFrameSize);
+   mEncAudioFifo = std::make_unique<FifoBuffer>(mDefaultFrameSize * mChannels * sizeof(int16_t));
 
    mEncAudioFifoOutBufSize = 2*MAX_AUDIO_PACKET_SIZE;
    // Allocate a buffer to read OUT of the FIFO into. The FIFO maintains its own buffer internally.
@@ -890,42 +889,27 @@ int ExportFFmpeg::EncodeAudio(AVPacketWrapper& pkt, int16_t* audio_samples, int
 
    pkt.SetStreamIndex(mEncAudioStream->GetIndex());
 
-   if (mFFmpeg->avcodec_send_frame != nullptr)
+   ret = mFFmpeg->avcodec_send_frame(
+      mEncAudioCodecCtx->GetWrappedValue(),
+      frame ? frame->GetWrappedValue() : nullptr);
+
+   while (ret >= 0)
    {
-      ret = mFFmpeg->avcodec_send_frame(
-         mEncAudioCodecCtx->GetWrappedValue(),
-         frame ? frame->GetWrappedValue() : nullptr);
+      ret = mFFmpeg->avcodec_receive_packet(
+         mEncAudioCodecCtx->GetWrappedValue(), pkt.GetWrappedValue());
 
-      while (ret >= 0)
+      if (ret == AUDACITY_AVERROR(EAGAIN) || ret == AUDACITY_AVERROR_EOF)
       {
-         ret = mFFmpeg->avcodec_receive_packet(
-            mEncAudioCodecCtx->GetWrappedValue(), pkt.GetWrappedValue());
-
-         if (ret == AUDACITY_AVERROR(EAGAIN) || ret == AUDACITY_AVERROR_EOF)
-         {
-            ret = 0;
-            break;
-         }
-         else if (ret < 0)
-            break;
-
-         if (!WritePacket(pkt))
-            return -1;
-
-         got_output = true;
+         ret = 0;
+         break;
       }
-   }
-   else
-   {
-      ret = mFFmpeg->avcodec_encode_audio2(
-         mEncAudioCodecCtx->GetWrappedValue(), pkt.GetWrappedValue(),
-         frame ? frame->GetWrappedValue() : nullptr, &got_output);
+      else if (ret < 0)
+         break;
 
-      if (ret == 0)
-      {
-         if (!WritePacket(pkt))
-            return -1;
-      }
+      if (!WritePacket(pkt))
+         return -1;
+
+      got_output = true;
    }
 
    if (ret < 0 && ret != AUDACITY_AVERROR_EOF) {
@@ -955,8 +939,8 @@ bool ExportFFmpeg::Finalize()
    {
       std::unique_ptr<AVPacketWrapper> pkt = mFFmpeg->CreateAVPacketWrapper();
 
-      const int nFifoBytes = mFFmpeg->av_fifo_size(
-         mEncAudioFifo->GetWrappedValue()); // any bytes left in audio FIFO?
+      const auto nFifoBytes =
+         mEncAudioFifo->GetAvailable(); // any bytes left in audio FIFO?
 
       int encodeResult = 0;
 
@@ -989,7 +973,7 @@ bool ExportFFmpeg::Finalize()
                          (mEncAudioCodecCtx->GetChannels() * sizeof(int16_t));
          }
 
-         wxLogDebug(wxT("FFmpeg : Audio FIFO still contains %d bytes, writing %d sample frame ..."),
+         wxLogDebug(wxT("FFmpeg : Audio FIFO still contains %lld bytes, writing %d sample frame ..."),
             nFifoBytes, frame_size);
 
          // Fill audio buffer with zeroes. If codec tries to read the whole buffer,
@@ -998,7 +982,7 @@ bool ExportFFmpeg::Finalize()
          //const AVCodec *codec = mEncAudioCodecCtx->codec;
 
          // Pull the bytes out from the FIFO and feed them to the encoder.
-         if (mFFmpeg->av_fifo_generic_read(mEncAudioFifo->GetWrappedValue(), mEncAudioFifoOutBuf.data(), nFifoBytes, nullptr) == 0)
+         if (mEncAudioFifo->Read(mEncAudioFifoOutBuf.data(), nFifoBytes) == nFifoBytes)
          {
             encodeResult = EncodeAudio(*pkt, mEncAudioFifoOutBuf.data(), frame_size);
          }
@@ -1052,14 +1036,9 @@ bool ExportFFmpeg::EncodeAudioFrame(int16_t *pFrame, size_t frameSize)
 
    nBytesToWrite = frameSize;
    pRawSamples  = (uint8_t*)pFrame;
-   if (mFFmpeg->av_fifo_realloc2(mEncAudioFifo->GetWrappedValue(), mFFmpeg->av_fifo_size(mEncAudioFifo->GetWrappedValue()) + frameSize) < 0) {
-      ShowExportErrorDialog("FFmpeg:905");
-      return false;
-   }
 
    // Put the raw audio samples into the FIFO.
-   ret = mFFmpeg->av_fifo_generic_write(
-      mEncAudioFifo->GetWrappedValue(), pRawSamples, nBytesToWrite, nullptr);
+   ret = mEncAudioFifo->Write(pRawSamples, nBytesToWrite);
 
    if (ret != nBytesToWrite) {
       ShowExportErrorDialog("FFmpeg:913");
@@ -1076,11 +1055,10 @@ bool ExportFFmpeg::EncodeAudioFrame(int16_t *pFrame, size_t frameSize)
    }
 
    // Read raw audio samples out of the FIFO in nAudioFrameSizeOut byte-sized groups to encode.
-   while (mFFmpeg->av_fifo_size(mEncAudioFifo->GetWrappedValue()) >= nAudioFrameSizeOut)
+   while (mEncAudioFifo->GetAvailable() >= nAudioFrameSizeOut)
    {
-      ret = mFFmpeg->av_fifo_generic_read(
-         mEncAudioFifo->GetWrappedValue(), mEncAudioFifoOutBuf.data(),
-         nAudioFrameSizeOut, nullptr);
+      mEncAudioFifo->Read(
+         mEncAudioFifoOutBuf.data(), nAudioFrameSizeOut);
 
       std::unique_ptr<AVPacketWrapper> pkt = mFFmpeg->CreateAVPacketWrapper();
 
